# Model API
Model API provides you a set of functions that easily make your model compatible with the `Trainer`,
`Synthesizer` and the Coqui Python API.

## Base Trainer Model

```{eval-rst}
.. autoclass:: TTS.model.BaseTrainerModel
    :members:
```

## Base TTS Model

```{eval-rst}
.. autoclass:: TTS.tts.models.base_tts.BaseTTS
    :members:
```

## Base Vocoder Model

```{eval-rst}
.. autoclass:: TTS.vocoder.models.base_vocoder.BaseVocoder
    :members:
```
